#!/usr/bin/env python
#-*- coding:utf-8 -*-

import sys
import click
from sggo import app

@click.group()
@click.pass_context
def cli(ctx):
    """ Plumber SG: a command-line tool for the View Plumber SG. """
    click.echo('Please report any bug or issue to <wei.zou@corerain.com>')

@cli.command()
@click.argument('sg_json', type=click.Path(exists=True))
@click.option('--host', type=str, default='127.0.0.1')
@click.option('--port', type=int, default=5000)
def view(sg_json, host, port):
    app.run(sg_json, host, port)

if __name__ == '__main__':
    cli()



import sys
import json
from flask import Flask, Response
from flask import render_template, jsonify
from collections import OrderedDict

app = Flask(__name__)

app.config['TEMPLATES_AUTO_RELOAD '] = True

SG = {}

@app.route('/')
def index():
    return render_template('graph.html')

@app.route('/sg')
def sg():
    return Response(json.dumps(SG), mimetype='application/json')

def run(sg, host, port):
    global SG
    with open(sg, 'r') as f:
        SG = json.loads(f.read())
    app.run(debug=False, host=host, port=port)

def run_with_json(sg, host, port):
    global SG
    SG = sg
    app.run(debug=False, host=host, port=port)

if __name__ == '__main__':
    sg = sys.argv[1]
    with open(sg, 'r') as f:
        SG = json.loads(f.read())
    app.run(debug=True)


#!/usr/bin/env python
"""
setup.py: utilities to install this package
"""
from setuptools import find_packages, setup


setup(name='SgGo',
      version='0.5.2',
      description='view sg graph.',
      author='Wei Zou',
      author_email='wei.zou@corerain.com',
      packages=find_packages(),
      py_modules=['sg_go'],
      license="MIT",
      package_data={
        'sggo': [
          'static/js/*.js', 
          'static/css/*.css', 
          'templates/*.html']
      },
      install_requires=[
      	"Flask",
        "click>=6.7"
      ],
      entry_points='''
        [console_scripts]
        sg_go=sg_go:cli
      '''
      )
